Commands class

Constructors

Commands()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

intent({required String name, Map<String, dynamic>? inputs, Map<String, dynamic>? data}) → Map<String, dynamic>
makeMoveVec({String? type, required List elements}) → Map<String, dynamic>
mergeCoins(dynamic destination, List sources) → Map<String, dynamic>
moveCall(dynamic input) → Map<String, dynamic>
publish({required List modules, required List<String> dependencies}) → Map<String, dynamic>
splitCoins(dynamic coin, List amounts) → Map<String, dynamic>
transferObjects(List objects, dynamic address) → Map<String, dynamic>
upgrade({required List modules, required List<String> dependencies, required String package, required dynamic ticket}) → Map<String, dynamic>