limits property
Define limits that are used when building the transaction. In general, we recommend using the protocol configuration instead of defining limits.
Implementation
Limits? limits;
Define limits that are used when building the transaction. In general, we recommend using the protocol configuration instead of defining limits.
Limits? limits;