protocolConfig property
Define a protocol config to build against, instead of having it fetched from the provider at build time.
Implementation
dynamic protocolConfig;
Define a protocol config to build against, instead of having it fetched from the provider at build time.
dynamic protocolConfig;