Transactions class

Simple helpers used to construct transactions:

Constructors

Transactions()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

makeMoveVec({required dynamic objects, String? type}) → Map<String, dynamic>
mergeCoins(dynamic destination, List sources) → Map<String, dynamic>
moveCall({required String target, List? typeArguments, List? arguments}) → Map<String, dynamic>
publish(List modules, List<String> dependencies) → Map<String, dynamic>
splitCoins(dynamic coin, dynamic amounts) → Map<String, dynamic>
transferObjects(List objects, dynamic address) → Map<String, dynamic>
upgrade({required List modules, required List<String> dependencies, required String packageId, required dynamic ticket}) → Map<String, dynamic>