JsonRpcResolutionClient class

TxResolutionClient backed by the JSON-RPC SuiClient.

Implemented types

Constructors

JsonRpcResolutionClient(SuiClient client)

Properties

client SuiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dryRunTransaction(Uint8List bytes, {String? signerAddress}) Future<DryRunTransactionBlockResponse>
override
getCoins(String owner, {String? coinType, String? cursor, int? limit}) Future<PaginatedCoins>
override
getNormalizedMoveFunction(String package, String module, String function) Future<SuiMoveNormalizedFunction>
override
getProtocolConfig() Future
The chain's protocol config (build limits), or null if the transport can't provide it (callers fall back to offline defaults / explicit limits).
override
getReferenceGasPrice() Future<BigInt>
override
multiGetObjects(List<String> objectIds, {SuiObjectDataOptions? options}) Future<List<SuiObjectResponse>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited