ResolvedPagination class

Constructors

ResolvedPagination({required bool descending, required int limit, String? after, String? before})
const

Properties

after String?
final
before String?
final
descending bool
final
hasBound bool
no setter
hashCode int
The hash code for this object.
no setterinherited
limit int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited