Keypair mixin

A keypair used for signing transactions.

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getKeyScheme() → SignatureScheme
Get the key scheme of the keypair: Secp256k1 or Ed25519
getPublicKey() → PublicKey
The public key for this keypair
getSecretKey() → Uint8List
The secret key for this keypair
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Uint8List bytes) → Uint8List
signData(Uint8List data) → Uint8List
Return the signature for the data
signPersonalMessage(Uint8List bytes) → SignatureWithBytes
signTransactionBlock(Uint8List bytes) → SignatureWithBytes
signWithIntent(Uint8List bytes, IntentScope intent) → SignatureWithBytes
toString() → String
A string representation of this object.
inherited
verify(Uint8List data, Uint8List signature, Uint8List publicKey) → bool
Verify signature
verifyPersonalMessage(Uint8List message, String signature) → bool
Verifies that the signature is valid for for the provided PersonalMessage
verifySerialized(Uint8List message, String signature, Uint8List publicKey) → bool
Verify serialized signature
verifyTransaction(Uint8List transaction, String signature) → bool
verifyWithIntent(Uint8List bytes, String signature, IntentScope intent) → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited