PublicKey mixin

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

equals(PublicKey publicKey) bool
Checks if two public keys are equal
flag() int
Return signature scheme flag of the public key
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64() String
Return the base-64 representation of the public key
toRawBytes() Uint8List
Return the byte array representation of the public key
toString() String
Return the base-64 representation of the public key
override
toSuiAddress() String
Return the Sui address associated with this public key
toSuiBytes() Uint8List
Raw public key bytes prefixed with the signature scheme flag.
toSuiPublicKey() String
Base-64 Sui public key: scheme flag concatenated with raw bytes.
verify(Uint8List data, Uint8List signature) bool
Verifies that the signature is valid for for the provided message
verifyAddress(String address) bool
Verifies that the public key is associated with the provided address
verifyPersonalMessage(Uint8List message, String signature) bool
verifyTransaction(Uint8List transaction, String signature) bool
verifyWithIntent(Uint8List bytes, String signature, IntentScope intent) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited