cryptography/mnemonics library

Functions

generateMnemonic({int strength = 128}) → String
isValidBIP32Path(String path) → bool
Parse and validate a path that is compliant to BIP-32 in form m/54'/784'/{account_index}'/{change_index}/{address_index} for Secp256k1 and m/74'/784'/{account_index}'/{change_index}/{address_index} for Secp256r1.
isValidHardenedPath(String path) → bool
Parse and validate a path that is compliant to SLIP-0010 in form m/44'/784'/{account_index}'/{change_index}'/{address_index}'.
isValidMnemonics(String mnemonics) → bool
mnemonicToSeed(String mnemonics) → Uint8List
Uses KDF to derive 64 bytes of key data from mnemonic with empty password.
mnemonicToSeedHex(String mnemonics) → String
Derive the seed in hex format from mnemonic with empty password.