PasskeyAuthentication class

The result of a WebAuthn assertion (navigator.credentials.get and friends).

Constructors

PasskeyAuthentication({required Uint8List authenticatorData, required Uint8List clientDataJson, required Uint8List signature})

Properties

authenticatorData Uint8List
final
clientDataJson Uint8List
The UTF-8 encoded client data JSON.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature Uint8List
The DER-encoded ECDSA signature.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited