PasskeyProvider class abstract

Bridges to a platform WebAuthn/credentials API. The actual key lives in the authenticator, so this is implemented by the host app (browser via JS interop, iOS/Android via platform channels) and supplied to PasskeyKeypair.

Constructors

PasskeyProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create() Future<PasskeyRegistration>
Registers a new passkey credential.
get(Uint8List challenge, [Uint8List? credentialId]) Future<PasskeyAuthentication>
Signs challenge with an existing credential, returning the assertion.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited