get abstract method
Signs challenge with an existing credential, returning the assertion.
Implementation
Future<PasskeyAuthentication> get(
Uint8List challenge, [
Uint8List? credentialId,
]);
Signs challenge with an existing credential, returning the assertion.
Future<PasskeyAuthentication> get(
Uint8List challenge, [
Uint8List? credentialId,
]);