PasskeyRegistration class

The public key and credential id returned when registering a new passkey.

Constructors

PasskeyRegistration({required Uint8List publicKeyDer, required Uint8List credentialId})

Properties

credentialId Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
publicKeyDer Uint8List
DER SubjectPublicKeyInfo for the secp256r1 key.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited