SignatureData class

Inheritance
  • Object
  • ECSignature
  • SignatureData

Constructors

SignatureData(BigInt r, BigInt s)
SignatureData.fromBytes(Uint8List data)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
r → BigInt
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s → BigInt
finalinherited

Methods

isNormalized(ECDomainParameters curveParams) → bool
Returns true if s is in lower-s form, false otherwise.
inherited
normalize(ECDomainParameters curveParams) → ECSignature
'normalize' this signature by converting its s to lower-s form if necessary This is required to validate this signature with some libraries such as libsecp256k1 which enforce lower-s form for all signatures to combat ecdsa signature malleability
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited