GraphQLError class

Constructors

GraphQLError({required String message, List<GraphQLErrorLocation> locations = const [], List? path, Map<String, dynamic>? extensions})
const

Properties

extensions Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
locations List<GraphQLErrorLocation>
final
message String
final
path List?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) GraphQLError?