GraphQLRequestException class

Implemented types

Constructors

GraphQLRequestException(String message, {int? statusCode, bool isCancelled = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isCancelled bool
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited