GraphQLTransport class

GraphQL-over-HTTP transport for Sui queries.

Constructors

GraphQLTransport(String endpoint, {Dio? dio, Map<String, String> headers = const {}})

Properties

endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String document, {Map<String, dynamic>? variables, String? operationName, Map<String, dynamic>? extensions, CancelToken? cancelToken}) Future<Map<String, dynamic>>
Executes document and returns its data, throwing on GraphQL errors.
request(String document, {Map<String, dynamic>? variables, String? operationName, Map<String, dynamic>? extensions, CancelToken? cancelToken}) Future<GraphQLResponse>
Executes document without discarding partial data or structured errors.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited