Fragment$CoreBalanceFields class
Constructors
- Fragment$CoreBalanceFields({Fragment$CoreBalanceFields$coinType? coinType, String? totalBalance, String? coinBalance, String? addressBalance})
-
Fragment$CoreBalanceFields.fromJson(Map<
String, dynamic> json) -
factory
Properties
- addressBalance → String?
-
final
- coinBalance → String?
-
final
- coinType → Fragment$CoreBalanceFields$coinType?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalBalance → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override