Fragment$TransactionHistoryFields$effects$balanceChanges$nodes class
Constructors
- Fragment$TransactionHistoryFields$effects$balanceChanges$nodes({String? amount, Fragment$TransactionHistoryFields$effects$balanceChanges$nodes$coinType? coinType, Fragment$TransactionHistoryFields$effects$balanceChanges$nodes$owner? owner})
-
Fragment$TransactionHistoryFields$effects$balanceChanges$nodes.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amount → String?
-
final
- coinType → Fragment$TransactionHistoryFields$effects$balanceChanges$nodes$coinType?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- owner → Fragment$TransactionHistoryFields$effects$balanceChanges$nodes$owner?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override