Fragment$TransactionHistoryFields$effects class
Constructors
- Fragment$TransactionHistoryFields$effects({String? timestamp, Enum$ExecutionStatus? status, Fragment$TransactionHistoryFields$effects$gasEffects? gasEffects, Fragment$TransactionHistoryFields$effects$balanceChanges? balanceChanges, Fragment$TransactionHistoryFields$effects$objectChanges? objectChanges})
-
Fragment$TransactionHistoryFields$effects.fromJson(Map<
String, dynamic> json) -
factory
Properties
- balanceChanges → Fragment$TransactionHistoryFields$effects$balanceChanges?
-
final
- gasEffects → Fragment$TransactionHistoryFields$effects$gasEffects?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- objectChanges → Fragment$TransactionHistoryFields$effects$objectChanges?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → Enum$ExecutionStatus?
-
final
- timestamp → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override