Fragment$TransactionHistoryFields$kind$$ProgrammableTransaction$commands class
Constructors
-
Fragment$TransactionHistoryFields$kind$$ProgrammableTransaction$commands({required Fragment$TransactionHistoryFields$kind$$ProgrammableTransaction$commands$pageInfo pageInfo, required List<
Fragment$TransactionHistoryFields$kind$$ProgrammableTransaction$commands$nodes> nodes}) -
Fragment$TransactionHistoryFields$kind$$ProgrammableTransaction$commands.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
nodes
→ List<
Fragment$TransactionHistoryFields$kind$$ProgrammableTransaction$commands$nodes> -
final
- pageInfo → Fragment$TransactionHistoryFields$kind$$ProgrammableTransaction$commands$pageInfo
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override