Fragment$TransactionHistoryFields class

Properties

digest String
final
effects Fragment$TransactionHistoryFields$effects?
final
hashCode int
The hash code for this object.
no setteroverride
kind Fragment$TransactionHistoryFields$kind?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender Fragment$TransactionHistoryFields$sender?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override