Query$GetCoinMetadata$coinMetadata class

Constructors

Query$GetCoinMetadata$coinMetadata({required String address, int? decimals, String? name, String? symbol, String? description, String? iconUrl})
Query$GetCoinMetadata$coinMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

address → String
final
decimals → int?
final
description → String?
final
hashCode → int
The hash code for this object.
no setteroverride
iconUrl → String?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override