Query$GetDynamicFields$object$dynamicFields$nodes class

Properties

address → String
final
hashCode → int
The hash code for this object.
no setteroverride
name → Query$GetDynamicFields$object$dynamicFields$nodes$name?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Query$GetDynamicFields$object$dynamicFields$nodes$value?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override