Query$GetMoveFunction$package$module$function$typeParameters class
Constructors
-
Query$GetMoveFunction$package$module$function$typeParameters({required List<
Enum$MoveAbility> constraints}) -
Query$GetMoveFunction$package$module$function$typeParameters.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
constraints
→ List<
Enum$MoveAbility> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override