Query$GetOwnedObjects$address$objects class

Properties

hashCode → int
The hash code for this object.
no setteroverride
nodes → List<Query$GetOwnedObjects$address$objects$nodes>
final
pageInfo → Query$GetOwnedObjects$address$objects$pageInfo
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override