Query$GetProtocolConfig$protocolConfigs class
Constructors
-
Query$GetProtocolConfig$protocolConfigs({required int protocolVersion, required List<
Query$GetProtocolConfig$protocolConfigs$configs> configs, required List<Query$GetProtocolConfig$protocolConfigs$featureFlags> featureFlags}) -
Query$GetProtocolConfig$protocolConfigs.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
configs
→ List<
Query$GetProtocolConfig$protocolConfigs$configs> -
final
-
featureFlags
→ List<
Query$GetProtocolConfig$protocolConfigs$featureFlags> -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- protocolVersion → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override