Query$MultiGetObjects$multiGetObjects class

Properties

address → String
final
asMoveObject → Query$MultiGetObjects$multiGetObjects$asMoveObject?
final
digest → String?
final
hashCode → int
The hash code for this object.
no setteroverride
owner → Fragment$CoreOwnerFields?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override