Query$SimulateTransaction$simulateTransaction class

Properties

effects → Query$SimulateTransaction$simulateTransaction$effects?
final
hashCode → int
The hash code for this object.
no setteroverride
outputs → List<Query$SimulateTransaction$simulateTransaction$outputs>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override