Query$TransactionHistoryByAddress$transactions class
Constructors
-
Query$TransactionHistoryByAddress$transactions({required Query$TransactionHistoryByAddress$transactions$pageInfo pageInfo, required List<
Fragment$TransactionHistoryFields> nodes}) -
Query$TransactionHistoryByAddress$transactions.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
nodes
→ List<
Fragment$TransactionHistoryFields> -
final
- pageInfo → Query$TransactionHistoryByAddress$transactions$pageInfo
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override