Variables$Query$EpochSummary class

Constructors

Variables$Query$EpochSummary({int? epochId})
factory
Variables$Query$EpochSummary.fromJson(Map<String, dynamic> data)
factory

Properties

epochId → int?
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override