Variables$Query$GetBalance class

Constructors

Variables$Query$GetBalance({required String address, required String coinType})
factory
Variables$Query$GetBalance.fromJson(Map<String, dynamic> data)
factory

Properties

address → String
no setter
coinType → String
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override