Variables$Query$GetCoinMetadata class

Constructors

Variables$Query$GetCoinMetadata({required String coinType})
factory
Variables$Query$GetCoinMetadata.fromJson(Map<String, dynamic> data)
factory

Properties

coinType → String
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override