Variables$Query$GetDynamicFields class

Constructors

Variables$Query$GetDynamicFields({required String parentId, int? first, String? after})
factory
Variables$Query$GetDynamicFields.fromJson(Map<String, dynamic> data)
factory

Properties

after → String?
no setter
first → int?
no setter
hashCode → int
The hash code for this object.
no setteroverride
parentId → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override