Variables$Query$GetMoveFunction class

Constructors

Variables$Query$GetMoveFunction({required String package, required String module, required String function})
factory
Variables$Query$GetMoveFunction.fromJson(Map<String, dynamic> data)
factory

Properties

function → String
no setter
hashCode → int
The hash code for this object.
no setteroverride
module → String
no setter
package → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override