Variables$Query$GetOwnedObjects class

Constructors

Variables$Query$GetOwnedObjects({required String address, String? type, int? first, String? after})
factory
Variables$Query$GetOwnedObjects.fromJson(Map<String, dynamic> data)
factory

Properties

address → String
no setter
after → String?
no setter
first → int?
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override