Variables$Query$GetTransaction class

Constructors

Variables$Query$GetTransaction({required String digest})
factory
Variables$Query$GetTransaction.fromJson(Map<String, dynamic> data)
factory

Properties

digest → String
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override