Variables$Query$ListTransactions class

Constructors

Variables$Query$ListTransactions({Input$TransactionFilter? filter, int? first, String? after, int? last, String? before})
factory
Variables$Query$ListTransactions.fromJson(Map<String, dynamic> data)
factory

Properties

after String?
no setter
before String?
no setter
filter Input$TransactionFilter?
no setter
first int?
no setter
hashCode int
The hash code for this object.
no setteroverride
last int?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override