Variables$Query$SimulateTransaction class

Constructors

Variables$Query$SimulateTransaction({required Map<String, dynamic> tx, bool? checksEnabled, bool? doGasSelection})
factory
Variables$Query$SimulateTransaction.fromJson(Map<String, dynamic> data)
factory

Properties

checksEnabled → bool?
no setter
doGasSelection → bool?
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tx → Map<String, dynamic>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override