Variables$Query$TransactionHistoryByAddress class

Constructors

Variables$Query$TransactionHistoryByAddress({required String address, required int first, String? before, required bool showBalanceChanges, required bool showObjectChanges})
factory
Variables$Query$TransactionHistoryByAddress.fromJson(Map<String, dynamic> data)
factory

Properties

address String
no setter
before String?
no setter
first int
no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBalanceChanges bool
no setter
showObjectChanges bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override