Enum$ConsensusObjectCancellationReason enum

Inheritance
  • Object
  • Enum
  • Enum$ConsensusObjectCancellationReason
Available extensions

Values

CANCELLED_READ → const Enum$ConsensusObjectCancellationReason
CONGESTED → const Enum$ConsensusObjectCancellationReason
RANDOMNESS_UNAVAILABLE → const Enum$ConsensusObjectCancellationReason
UNKNOWN → const Enum$ConsensusObjectCancellationReason
$unknown → const Enum$ConsensusObjectCancellationReason

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Enum$ConsensusObjectCancellationReason>
A constant List of the values in this enum, in order of their declaration.