Input$AddressKey class
Constructors
- Input$AddressKey({String? address, int? atCheckpoint, String? name, int? rootVersion})
-
factory
-
Input$AddressKey.fromJson(Map<
String, dynamic> data) -
factory
Properties
- address → String?
-
no setter
- atCheckpoint → int?
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String?
-
no setter
- rootVersion → int?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override