Input$DynamicFieldName class

Constructors

Input$DynamicFieldName({String? bcs, String? literal, String? type})
factory
Input$DynamicFieldName.fromJson(Map<String, dynamic> data)
factory

Properties

bcs String?
no setter
hashCode int
The hash code for this object.
no setteroverride
literal String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override