Input$ObjectFilter class
Constructors
- Input$ObjectFilter({String? owner, Enum$OwnerKind? ownerKind, String? type})
-
factory
-
Input$ObjectFilter.fromJson(Map<
String, dynamic> data) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- owner → String?
-
no setter
- ownerKind → Enum$OwnerKind?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override