TransactionDigestPage class

Constructors

TransactionDigestPage({required List<String> digests, required bool hasNextPage, String? endCursor})

Properties

digests → List<String>
final
endCursor → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hasNextPage → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited