SuiGrpcClientOptions class
Constructors
- SuiGrpcClientOptions({required String baseUrl, ClientChannel? customChannel, required int port})
Properties
- baseUrl → String
-
final
- customChannel → ClientChannel?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- port → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited