GrpcCoreClient class

Constructors

GrpcCoreClient(SuiGrpcClient _client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

defaultNameServiceName(String address) Future<String?>
executeTransaction(Uint8List transactionBytes, List<String> signatures, {TransactionIncludeOptions? include}) Future<TransactionResponse>
getBalance(String owner, {String coinType = '0x2::sui::SUI'}) Future<Balance>
getChainIdentifier() Future<String>
getCoinMetadata(String coinType) Future<CoinMetadata?>
getCurrentSystemState() Future<SystemState>
getMoveFunction(String packageId, String moduleName, String functionName) Future<MoveFunction>
getObjects(List<String> ids, {ObjectIncludeOptions? include}) Future<List<ObjectResult>>
getReferenceGasPrice() Future<String>
getTransaction(String digest, {TransactionIncludeOptions? include}) Future<TransactionResponse>
listBalances(String owner) Future<List<Balance>>
listCoins(String owner, {String coinType = '0x2::sui::SUI', String? cursor, int? limit}) Future<Page<CoinData>>
listDynamicFields(String parentId, {String? cursor, int? limit}) Future<Page<DynamicFieldEntry>>
listOwnedObjects(String owner, {String? objectType, String? cursor, int? limit, ObjectIncludeOptions? include}) Future<Page<ObjectData>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
simulateTransaction(Transaction transactionBlock, {TransactionIncludeOptions? include, bool? doGasSelection}) Future<TransactionResponse>
toString() String
A string representation of this object.
inherited
verifyZkLoginSignature(Uint8List bytes, String signature, {String? address}) Future<VerifySignatureResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited