reason property

  1. @TagNumber.new(3)
String get reason

The reason of the field-level error. This is a constant value that identifies the proximate cause of the field-level error. It should uniquely identify the type of the FieldViolation within the scope of the google.rpc.ErrorInfo.domain. This should be at most 63 characters and match a regular expression of [A-Z][A-Z0-9_]+[A-Z0-9], which represents UPPER_SNAKE_CASE.

Implementation

@$pb.TagNumber(3)
$core.String get reason => $_getSZ(2);
  1. @TagNumber.new(3)
set reason (String value)

Implementation

@$pb.TagNumber(3)
set reason($core.String value) => $_setString(2, value);