TransactionEffects class

The effects of executing a transaction.

Available extensions

Constructors

TransactionEffects({Bcs? bcs, String? digest, int? version, ExecutionStatus? status, Int64? epoch, GasCostSummary? gasUsed, String? transactionDigest, ChangedObject? gasObject, String? eventsDigest, Iterable<String>? dependencies, Int64? lamportVersion, Iterable<ChangedObject>? changedObjects, Iterable<UnchangedConsensusObject>? unchangedConsensusObjects, String? auxiliaryDataDigest, Iterable<ObjectReference>? unchangedLoadedRuntimeObjects})
factory
TransactionEffects.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
TransactionEffects.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

auxiliaryDataDigest String
Auxiliary data that are not protocol-critical, generated as part of the effects but are stored separately. Storing it separately allows us to avoid bloating the effects with data that are not critical. It also provides more flexibility on the format and type of the data.
getter/setter pair
bcs Bcs
This TransactionEffects serialized as BCS.
getter/setter pair
changedObjects → PbList<ChangedObject>
Objects whose state are changed by this transaction.
no setter
dependencies → PbList<String>
The set of transaction digests this transaction depends on.
no setter
digest String
The digest of this TransactionEffects.
getter/setter pair
epoch ↔ Int64
The epoch when this transaction was executed.
getter/setter pair
eventsDigest String
The digest of the events emitted during execution, can be None if the transaction does not emit any event.
getter/setter pair
gasObject ChangedObject
Information about the gas object. Also present in the changed_objects vector.
getter/setter pair
gasUsed GasCostSummary
The gas used by this transaction.
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
lamportVersion ↔ Int64
The version number of all the written objects (excluding packages) by this transaction.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ExecutionStatus
The status of the execution.
getter/setter pair
transactionDigest String
The transaction digest.
getter/setter pair
unchangedConsensusObjects → PbList<UnchangedConsensusObject>
Consensus objects that are not mutated in this transaction. Unlike owned objects, read-only consensus objects' version are not committed in the transaction, and in order for a node to catch up and execute it without consensus sequencing, the version needs to be committed in the effects.
no setter
unchangedLoadedRuntimeObjects → PbList<ObjectReference>
no setter
unknownFields → UnknownFieldSet
no setterinherited
version int
Version of this TransactionEffects.
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAuxiliaryDataDigest() → void
clearBcs() → void
clearDigest() → void
clearEpoch() → void
clearEventsDigest() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearGasObject() → void
clearGasUsed() → void
clearLamportVersion() → void
clearStatus() → void
clearTransactionDigest() → void
clearVersion() → void
clone() TransactionEffects
Creates a deep copy of the fields in this message.
copyWith(void updates(TransactionEffects)) TransactionEffects
Apply updates to a copy of this message.
createEmptyInstance() TransactionEffects
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureBcs() Bcs
ensureGasObject() ChangedObject
ensureGasUsed() GasCostSummary
ensureStatus() ExecutionStatus
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAuxiliaryDataDigest() bool
hasBcs() bool
hasDigest() bool
hasEpoch() bool
hasEventsDigest() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasGasObject() bool
hasGasUsed() bool
hasLamportVersion() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasStatus() bool
hasTransactionDigest() bool
hasVersion() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited