auxiliaryDataDigest property

  1. @TagNumber.new(14)
String get auxiliaryDataDigest

Auxiliary data that are not protocol-critical, generated as part of the effects but are stored separately. Storing it separately allows us to avoid bloating the effects with data that are not critical. It also provides more flexibility on the format and type of the data.

Implementation

@$pb.TagNumber(14)
$core.String get auxiliaryDataDigest => $_getSZ(13);
  1. @TagNumber.new(14)
set auxiliaryDataDigest (String value)

Implementation

@$pb.TagNumber(14)
set auxiliaryDataDigest($core.String value) => $_setString(13, value);