pure property
A move value serialized as BCS.
For normal operations this is required to be a move primitive type and not contain structs or objects.
Implementation
@$pb.TagNumber(2)
$core.List<$core.int> get pure => $_getN(1);
A move value serialized as BCS.
For normal operations this is required to be a move primitive type and not contain structs or objects.
@$pb.TagNumber(2)
$core.List<$core.int> get pure => $_getN(1);