module property
The specific module in the package containing the function.
Implementation
@$pb.TagNumber(2)
$core.String get module => $_getSZ(1);
Implementation
@$pb.TagNumber(2)
set module($core.String value) => $_setString(1, value);
The specific module in the package containing the function.
@$pb.TagNumber(2)
$core.String get module => $_getSZ(1);
@$pb.TagNumber(2)
set module($core.String value) => $_setString(1, value);