CoinData class

Constructors

CoinData({required String objectId, required String version, required String digest, required Owner owner, required String type, required String balance})
const

Properties

balance String
final
digest String
final
hashCode int
The hash code for this object.
no setterinherited
objectId String
final
owner Owner
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited