Event class

Constructors

Event({required String packageId, required String module, required String sender, required String eventType, required Uint8List bcs, Map<String, dynamic>? json, String? checkpoint, String? transactionDigest, int? eventIndex})
const

Properties

bcs → Uint8List
final
checkpoint → String?
final
eventIndex → int?
final
eventType → String
final
hashCode → int
The hash code for this object.
no setterinherited
json → Map<String, dynamic>?
final
module → String
final
packageId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String
final
transactionDigest → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited