GasObject class

Constructors

GasObject({required String objectId, String? inputState, String? outputState})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputState → String?
final
objectId → String
final
outputState → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited