MoveAbortLocation class

Constructors

MoveAbortLocation({required String package, required String module, required int function, required int instruction, String? functionName})
const

Properties

function int
final
functionName String?
final
hashCode int
The hash code for this object.
no setterinherited
instruction int
final
module String
final
package String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited