MoveFunction class

Constructors

MoveFunction({required String name, required String visibility, required bool isEntry, required List<TypeParameter> typeParameters, required List<NormalizedMoveType> parameters, required List<NormalizedMoveType> returnTypes})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isEntry bool
final
name String
final
parameters List<NormalizedMoveType>
final
returnTypes List<NormalizedMoveType>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeParameters List<TypeParameter>
final
visibility String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited