MoveTypeStruct class

Inheritance

Constructors

MoveTypeStruct({required String address, required String module, required String name, required List<NormalizedMoveType> typeArguments})
const

Properties

address → String
final
hashCode → int
The hash code for this object.
no setterinherited
module → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeArguments → List<NormalizedMoveType>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited