ObjectIncludeOptions class

Constructors

ObjectIncludeOptions({bool content = false, bool previousTransaction = false, bool objectBcs = false, bool json = false, bool display = false})
const

Properties

content → bool
final
display → bool
final
hashCode → int
The hash code for this object.
no setterinherited
json → bool
final
objectBcs → bool
final
previousTransaction → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited