Page<T> class

Constructors

Page({required List<T> data, required bool hasNextPage, String? nextCursor, String? startCursor})
const

Properties

data → List<T>
final
hashCode → int
The hash code for this object.
no setterinherited
hasNextPage → bool
final
nextCursor → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startCursor → String?
For reading back from this page. Only the ledger queries report one.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited