TransactionIncludeOptions class

Constructors

TransactionIncludeOptions({bool transaction = false, bool effects = false, bool events = false, bool balanceChanges = false, bool objectTypes = false, bool bcs = false, bool commandResults = false})
const

Properties

balanceChanges bool
final
bcs bool
final
commandResults bool
final
effects bool
final
events bool
final
hashCode int
The hash code for this object.
no setterinherited
objectTypes bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transaction bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited