DevInspectResults class abstract

Available extensions
Annotations
  • @freezed

Constructors

DevInspectResults({required TransactionEffects effects, required List<SuiEvent> events, String? error, List<SuiExecutionResult>? results})
const
factory
DevInspectResults.fromJson(Map<String, dynamic> json)
factory

Properties

effects TransactionEffects
no setterinherited
error String?
no setterinherited
events List<SuiEvent>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
results List<SuiExecutionResult>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_DevInspectResults value)) → TResult

Available on DevInspectResults, provided by the DevInspectResultsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_DevInspectResults value)?) → TResult?

Available on DevInspectResults, provided by the DevInspectResultsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_DevInspectResults value)?, {required TResult orElse()}) → TResult

Available on DevInspectResults, provided by the DevInspectResultsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(TransactionEffects effects, List<SuiEvent> events, String? error, List<SuiExecutionResult>? results)?, {required TResult orElse()}) → TResult

Available on DevInspectResults, provided by the DevInspectResultsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this DevInspectResults to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(TransactionEffects effects, List<SuiEvent> events, String? error, List<SuiExecutionResult>? results)) → TResult

Available on DevInspectResults, provided by the DevInspectResultsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(TransactionEffects effects, List<SuiEvent> events, String? error, List<SuiExecutionResult>? results)?) → TResult?

Available on DevInspectResults, provided by the DevInspectResultsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited