DynamicFieldPage class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
DynamicFieldPage({required List<
DynamicFieldInfo> data, String? nextCursor, required bool hasNextPage}) -
constfactory
-
DynamicFieldPage.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
data
→ List<
DynamicFieldInfo> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNextPage → bool
-
no setterinherited
- nextCursor → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_DynamicFieldPage value)) → TResult -
Available on DynamicFieldPage, provided by the DynamicFieldPagePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_DynamicFieldPage value)?) → TResult? -
Available on DynamicFieldPage, provided by the DynamicFieldPagePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_DynamicFieldPage value)?, {required TResult orElse()}) → TResult -
Available on DynamicFieldPage, provided by the DynamicFieldPagePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(List< DynamicFieldInfo> data, String? nextCursor, bool hasNextPage)?, {required TResult orElse()}) → TResult -
Available on DynamicFieldPage, provided by the DynamicFieldPagePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this DynamicFieldPage to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(List< DynamicFieldInfo> data, String? nextCursor, bool hasNextPage)) → TResult -
Available on DynamicFieldPage, provided by the DynamicFieldPagePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(List< DynamicFieldInfo> data, String? nextCursor, bool hasNextPage)?) → TResult? -
Available on DynamicFieldPage, provided by the DynamicFieldPagePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited