Paged<T> class abstract

Available extensions
Annotations
  • @Freezed.new(genericArgumentFactories: true)

Constructors

Paged({required T data, dynamic nextCursor, required bool hasNextPage})
const
factory
Paged.fromJson(Map<String, dynamic> json, T fromJsonT(Object? json))
factory

Properties

data → T
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hasNextPage bool
no setterinherited
nextCursor → dynamic
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Paged<T> value)) → TResult

Available on Paged<T>, provided by the PagedPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Paged<T> value)?) → TResult?

Available on Paged<T>, provided by the PagedPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Paged<T> value)?, {required TResult orElse()}) → TResult

Available on Paged<T>, provided by the PagedPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(T data, dynamic nextCursor, bool hasNextPage)?, {required TResult orElse()}) → TResult

Available on Paged<T>, provided by the PagedPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object? toJsonT(T)) Map<String, dynamic>
Serializes this Paged to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(T data, dynamic nextCursor, bool hasNextPage)) → TResult

Available on Paged<T>, provided by the PagedPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(T data, dynamic nextCursor, bool hasNextPage)?) → TResult?

Available on Paged<T>, provided by the PagedPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited