SuiEvent class abstract

Available extensions
Annotations
  • @freezed

Constructors

SuiEvent({required EventId id, required String packageId, required String transactionModule, required String sender, required String type, required Map<String, dynamic>? parsedJson, required String? bcs})
const
factory
SuiEvent.fromJson(Map<String, dynamic> json)
factory

Properties

bcs String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id EventId
no setterinherited
packageId String
no setterinherited
parsedJson Map<String, dynamic>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender String
no setterinherited
transactionModule String
no setterinherited
type String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SuiEvent value)) → TResult

Available on SuiEvent, provided by the SuiEventPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SuiEvent value)?) → TResult?

Available on SuiEvent, provided by the SuiEventPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SuiEvent value)?, {required TResult orElse()}) → TResult

Available on SuiEvent, provided by the SuiEventPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(EventId id, String packageId, String transactionModule, String sender, String type, Map<String, dynamic>? parsedJson, String? bcs)?, {required TResult orElse()}) → TResult

Available on SuiEvent, provided by the SuiEventPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SuiEvent to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(EventId id, String packageId, String transactionModule, String sender, String type, Map<String, dynamic>? parsedJson, String? bcs)) → TResult

Available on SuiEvent, provided by the SuiEventPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(EventId id, String packageId, String transactionModule, String sender, String type, Map<String, dynamic>? parsedJson, String? bcs)?) → TResult?

Available on SuiEvent, provided by the SuiEventPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited