BatchStatusFaucetResponse class

Constructors

BatchStatusFaucetResponse(BatchSendStatusType status, String? error)
BatchStatusFaucetResponse.fromJson(dynamic data)
factory

Properties

error → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ BatchSendStatusType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → ObjectId
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited