CoinMetadataStruct class

Constructors

CoinMetadataStruct(int decimals, String name, String symbol, String description, String iconUrl, ObjectId id)
CoinMetadataStruct.fromJson(dynamic data)
factory

Properties

decimals ↔ int
getter/setter pair
description ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconUrl ↔ String
getter/setter pair
id ↔ String
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited