PaginatedObjectsResponse class

Constructors

PaginatedObjectsResponse(List<SuiObjectResponse> data, String nextCursor, bool hasNextPage)
PaginatedObjectsResponse.fromJson(dynamic data)
factory

Properties

data ↔ List<SuiObjectResponse>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasNextPage ↔ bool
getter/setter pair
nextCursor ↔ TransactionDigest
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → TransactionDigest
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited