SuiMoveObject class

Constructors

SuiMoveObject(String dataType, String type, ObjectContentFields fields, bool? hasPublicTransfer)
SuiMoveObject.fromJson(dynamic data)
factory

Properties

dataType TransactionDigest
getter/setter pair
fields ObjectContentFields
Fields and values stored inside the Move object
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasPublicTransfer bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TransactionDigest
Move type (e.g., "0x2::coin::Coin<0x2::sui::SUI>")
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() TransactionDigest
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited