SuiObjectRef class

Implementers

Constructors

SuiObjectRef(TransactionDigest digest, String objectId, dynamic version)
SuiObjectRef.fromJson(dynamic data)
factory

Properties

digest ↔ TransactionDigest
Base64 string representing the object digest
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectId ↔ TransactionDigest
Hex code as string representing the object id
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ int
Object version
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → TransactionDigest
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited