SharedObjectRef class

A reference to a shared object.

Constructors

SharedObjectRef(String objectId, dynamic initialSharedVersion, bool mutable)

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialSharedVersion ↔ int
The version the object was shared at
getter/setter pair
mutable ↔ bool
Whether reference is mutable
getter/setter pair
objectId ↔ String
Hex code as string representing the object id
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited