CertifiedTransaction class

Constructors

CertifiedTransaction(TransactionDigest transactionDigest, SuiTransactionData data, List<String> txSignatures, AuthorityQuorumSignInfo authSignInfo)
CertifiedTransaction.fromJson(dynamic data)
factory

Properties

authSignInfo ↔ AuthorityQuorumSignInfo
getter/setter pair
data ↔ SuiTransactionData
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionDigest ↔ String
getter/setter pair
txSignatures ↔ List<String>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited