ExecutionStatus class

Constructors

ExecutionStatus(ExecutionStatusType status, String? error)
ExecutionStatus.fromJson(dynamic data)
factory

Properties

error ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ ExecutionStatusType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited