MoveCall class

Constructors

MoveCall(dynamic package, String module, String function, List<String>? typeArguments, List? arguments)
MoveCall.fromJson(dynamic data)
factory

Properties

arguments ↔ List?
getter/setter pair
function ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
module ↔ String
getter/setter pair
package ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeArguments ↔ List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited