PaginatedTransactionResponse class

Constructors

PaginatedTransactionResponse(List<SuiTransactionBlockResponse> data, String? nextCursor, bool hasNextPage)
PaginatedTransactionResponse.fromJson(dynamic data)
factory

Properties

data ↔ List<SuiTransactionBlockResponse>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasNextPage ↔ bool
getter/setter pair
nextCursor ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited