SuiExecuteTransactionResponse class

Constructors

SuiExecuteTransactionResponse(TransactionDigest digest, TransactionEffects? effects, String? timestampMs, String? checkpoint, TransactionEvents events, SuiTransactionBlock? transaction, bool? confirmedLocalExecution, List? objectChanges, List<BalanceChange> balanceChanges, List? errors, Map<String, dynamic> json)
SuiExecuteTransactionResponse.fromJson(dynamic data)
factory

Properties

balanceChanges ↔ List<BalanceChange>
getter/setter pair
checkpoint ↔ String?
getter/setter pair
confirmedLocalExecution ↔ bool?
getter/setter pair
digest ↔ String
getter/setter pair
effects ↔ TransactionEffects?
getter/setter pair
errors ↔ List?
getter/setter pair
events ↔ TransactionEvents
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
json ↔ Map<String, dynamic>
getter/setter pair
objectChanges ↔ List?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestampMs ↔ String?
getter/setter pair
transaction ↔ SuiTransactionBlock?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited