SuiTransactionData class

Constructors

SuiTransactionData(List<SuiTransactionKind> transactions, SuiAddress sender, SuiGasData gasData)
SuiTransactionData.fromJson(dynamic data)
factory

Properties

gasData ↔ SuiGasData
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender ↔ String
getter/setter pair
transactions ↔ List<SuiTransactionKind>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited