SuiTransactionKind class

Constructors

SuiTransactionKind(TransferObject? transferObject, SuiMovePackage? publish, MoveCall? call, SuiTransferSui? transferSui, SuiChangeEpoch? changeEpoch, Pay? pay, PaySui? paySui, PayAllSui? payAllSui)
SuiTransactionKind.fromJson(dynamic data)
factory

Properties

call ↔ MoveCall?
getter/setter pair
changeEpoch ↔ SuiChangeEpoch?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pay ↔ Pay?
getter/setter pair
payAllSui ↔ PayAllSui?
getter/setter pair
paySui ↔ PaySui?
getter/setter pair
publish ↔ SuiMovePackage?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferObject ↔ TransferObject?
getter/setter pair
transferSui ↔ SuiTransferSui?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited