SuiTransactionResponse class

Constructors

SuiTransactionResponse(CertifiedTransaction certificate, TransactionEffects effects, int? timestampMillisecond, SuiParsedTransactionResponse? parsedData)
SuiTransactionResponse.fromJson(dynamic data)
factory

Properties

certificate ↔ CertifiedTransaction
getter/setter pair
effects ↔ TransactionEffects
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parsedData ↔ SuiParsedTransactionResponse?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestampMillisecond ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited