TransactionEffects class

Constructors

TransactionEffects(ExecutionStatus status, GasCostSummary gasUsed, List<SuiObjectRef>? sharedObjects, TransactionDigest transactionDigest, List<OwnedObjectRef>? created, List<OwnedObjectRef> mutated, List<OwnedObjectRef>? unwrapped, List<SuiObjectRef>? deleted, List<SuiObjectRef>? wrapped, OwnedObjectRef gasObject, List? events, List<String> dependencies, Map<String, dynamic> json)
TransactionEffects.fromJson(dynamic data)
factory

Properties

created ↔ List<OwnedObjectRef>?
ObjectRef and owner of new objects created
getter/setter pair
deleted ↔ List<SuiObjectRef>?
Object Refs of objects now deleted (the old refs)
getter/setter pair
dependencies ↔ List<String>
The set of transaction digests this transaction depends on
getter/setter pair
events ↔ List?
The events emitted during execution. Note that only successful transactions emit events
getter/setter pair
gasObject ↔ OwnedObjectRef
The updated gas object reference. Have a dedicated field for convenient access. It's also included in mutated.
getter/setter pair
gasUsed ↔ GasCostSummary
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
json ↔ Map<String, dynamic>
getter/setter pair
mutated ↔ List<OwnedObjectRef>
ObjectRef and owner of mutated objects, including gas object
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedObjects ↔ List<SuiObjectRef>?
The object references of the shared objects used in this transaction. Empty if no shared objects were used.
getter/setter pair
status ↔ ExecutionStatus
The status of the execution
getter/setter pair
transactionDigest ↔ String
The transaction digest
getter/setter pair
unwrapped ↔ List<OwnedObjectRef>?
ObjectRef and owner of objects that are unwrapped in this transaction. Unwrapped objects are objects that were wrapped into other objects in the past, and just got extracted out.
getter/setter pair
wrapped ↔ List<SuiObjectRef>?
Object refs of objects now wrapped in other objects
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited