Inputs class

Constructors

Inputs()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fundsWithdrawal({required BigInt maxAmount, required String coinType, bool fromSponsor = false}) Map<String, dynamic>
Reserves maxAmount of coinType from the sender's (or sponsor's) address balance. A matching 0x2::coin::redeem_funds turns it into a Coin<T>.
objectRef(SuiObjectRef data) Map<String, dynamic>
pure(dynamic data, [String? type]) Map<String, dynamic>
receivingRef(SuiObjectRef data) Map<String, dynamic>
sharedObjectRef(dynamic data) Map<String, dynamic>