BuildOptions class
Properties
client
↔ SuiCoreClient ?
Transport-agnostic client used for all build-time reads (coins, objects,
gas price, dry run, move-function signatures). Pass suiGrpcClient.core
or suiGraphQLClient.core.
getter/setter pair
hashCode
→ int
The hash code for this object.
no setter inherited
limits
↔ Limits
Define limits that are used when building the transaction. In general, we recommend using the protocol configuration instead of defining limits.
getter/setter pair
onlyTransactionKind
↔ bool
getter/setter pair
protocolConfig
↔ Limits
Define a protocol config to build against, instead of having it fetched from the provider at build time.
getter/setter pair
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited