BuildOptions class

Implementers

Constructors

BuildOptions({SuiClient? client, bool onlyTransactionKind = false, dynamic protocolConfig, Limits limits})

Properties

client SuiClient?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
limits Limits
Define limits that are used when building the transaction. In general, we recommend using the protocol configuration instead of defining limits.
getter/setter pair
onlyTransactionKind bool
getter/setter pair
protocolConfig Limits
Define a protocol config to build against, instead of having it fetched from the provider at build time.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited