builder/tx_resolution_client library
Classes
- JsonRpcResolutionClient
- TxResolutionClient backed by the JSON-RPC SuiClient.
- TxResolutionClient
- Transport-agnostic view of the chain reads the transaction builder needs at build time (coin selection, object resolution, gas price, dry run, move function signatures, protocol limits).