graphql/graphql_operation library
Classes
- GraphQLNoVariables
- Variables value for a generated operation that declares no variables.
-
GraphQLOperation<
TData, TVariables> - A schema-checked GraphQL document with its generated Dart data types.
-
TypedGraphQLResponse<
TData> - A typed GraphQL response that can contain both partial data and errors.
Typedefs
-
GraphQLDataDecoder<
T> = T Function(Map< String, dynamic> json) -
GraphQLVariablesEncoder<
T> = Map< String, dynamic> Function(T value)