GraphQLOperation<TData, TVariables> class

A schema-checked GraphQL document with its generated Dart data types.

Constructors

GraphQLOperation({required DocumentNode document, required String operationName, required GraphQLDataDecoder<TData> decodeData, required GraphQLVariablesEncoder<TVariables> encodeVariables})

Properties

decodeData → GraphQLDataDecoder<TData>
final
document → String
final
encodeVariables → GraphQLVariablesEncoder<TVariables>
final
hashCode → int
The hash code for this object.
no setterinherited
operationName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited