TypedGraphQLResponse<TData> class
A typed GraphQL response that can contain both partial data and errors.
Constructors
-
TypedGraphQLResponse({required TData? data, required List<
GraphQLError> errors, Map<String, dynamic> ? extensions}) -
const
Properties
- data → TData?
-
final
-
errors
→ List<
GraphQLError> -
final
-
extensions
→ Map<
String, dynamic> ? -
final
- hasErrors → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited