GraphQLResponse class

Constructors

GraphQLResponse({required Map<String, dynamic>? data, required List<GraphQLError> errors, Map<String, dynamic>? extensions})
const

Properties

data → Map<String, dynamic>?
final
errors → List<GraphQLError>
final
extensions → Map<String, dynamic>?
final
hasErrors → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited