Query$EventsByModule$events$pageInfo class

Constructors

Query$EventsByModule$events$pageInfo({required bool hasNextPage, String? endCursor})
Query$EventsByModule$events$pageInfo.fromJson(Map<String, dynamic> json)
factory

Properties

endCursor → String?
final
hashCode → int
The hash code for this object.
no setteroverride
hasNextPage → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override