Query$GetEpoch$epoch class

Constructors

Query$GetEpoch$epoch({required int epochId, String? referenceGasPrice, String? startTimestamp})
Query$GetEpoch$epoch.fromJson(Map<String, dynamic> json)
factory

Properties

epochId int
final
hashCode int
The hash code for this object.
no setteroverride
referenceGasPrice String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override