Variables$Query$MultiGetObjects class

Constructors

Variables$Query$MultiGetObjects({required List<Input$ObjectKey> keys})
factory
Variables$Query$MultiGetObjects.fromJson(Map<String, dynamic> data)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
keys List<Input$ObjectKey>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override