Input$EventFilter class

Constructors

Input$EventFilter({int? afterCheckpoint, int? atCheckpoint, int? beforeCheckpoint, String? module, String? sender, String? type})
factory
Input$EventFilter.fromJson(Map<String, dynamic> data)
factory

Properties

afterCheckpoint → int?
no setter
atCheckpoint → int?
no setter
beforeCheckpoint → int?
no setter
hashCode → int
The hash code for this object.
no setteroverride
module → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String?
no setter
type → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override