Input$TransactionFilter class
Constructors
- Input$TransactionFilter({String? affectedAddress, String? affectedObject, int? afterCheckpoint, int? atCheckpoint, int? beforeCheckpoint, String? function, Enum$TransactionKindInput? kind, String? sentAddress})
-
factory
-
Input$TransactionFilter.fromJson(Map<
String, dynamic> data) -
factory
Properties
- affectedAddress → String?
-
no setter
- affectedObject → String?
-
no setter
- afterCheckpoint → int?
-
no setter
- atCheckpoint → int?
-
no setter
- beforeCheckpoint → int?
-
no setter
- function → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- kind → Enum$TransactionKindInput?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sentAddress → String?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override