SenderTransaction class
Constructors
-
SenderTransaction({required String digest, required int? timestampMs, required bool success, required List<
TxBalanceChange> balanceChanges, String? senderAddress, bool isProgrammableTransaction = false, List<String> commandTypes = const [], bool commandTypesTruncated = false, TransactionGasSummary? gasSummary, List<TxObjectChange> objectChanges = const [], bool balanceChangesTruncated = false, bool objectChangesTruncated = false})
Properties
-
balanceChanges
→ List<
TxBalanceChange> -
final
- balanceChangesTruncated → bool
-
final
-
commandTypes
→ List<
String> -
final
- commandTypesTruncated → bool
-
final
- digest → String
-
final
- gasSummary → TransactionGasSummary?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isProgrammableTransaction → bool
-
final
-
objectChanges
→ List<
TxObjectChange> -
final
- objectChangesTruncated → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderAddress → String?
-
final
- success → bool
-
final
- timestampMs → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited