SuiGrpcClient class
- Available extensions
Constructors
- SuiGrpcClient(SuiGrpcClientOptions options)
Properties
- core ↔ GrpcCoreClient
-
latefinal
- forkingService ↔ ForkingServiceClient
-
Admin-only service on
sui-forkinstances (same host/port as the regular services).latefinal - hashCode → int
-
The hash code for this object.
no setterinherited
- ledgerService ↔ LedgerServiceClient
-
latefinal
- movePackageService ↔ MovePackageServiceClient
-
latefinal
- nameService ↔ NameServiceClient
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signatureVerificationService ↔ SignatureVerificationServiceClient
-
latefinal
- stateService ↔ StateServiceClient
-
latefinal
- subscriptionService ↔ SubscriptionServiceClient
-
latefinal
- transactionExecutionService ↔ TransactionExecutionServiceClient
-
latefinal
Methods
-
buildTransaction(
Transaction tx, {String? sender}) → Future< Uint8List> -
Available on SuiGrpcClient, provided by the SuiGrpcClientTransactions extension
Buildstxto BCS bytes, resolving coins/objects/gas over gRPC. -
defaultNameServiceName(
String address) → Future< String?> -
executeTransaction(
Uint8List transactionBytes, List< String> signatures, {TransactionIncludeOptions? include}) → Future<TransactionResponse> -
getBalance(
String owner, {String coinType = '0x2::sui::SUI'}) → Future< Balance> -
getChainIdentifier(
) → Future< String> -
getCoinMetadata(
String coinType) → Future< CoinMetadata?> -
getCurrentSystemState(
) → Future< SystemState> -
getDynamicFieldObject(
String parentId, String nameType, dynamic nameValue, {ObjectIncludeOptions? include}) → Future< ObjectData?> -
The
suix_getDynamicFieldObjectequivalent: derives the field UID fromparentId+ the encoded name and fetches it (nullif absent). -
getMoveFunction(
String packageId, String moduleName, String functionName) → Future< MoveFunction> -
getObjects(
List< String> ids, {ObjectIncludeOptions? include}) → Future<List< ObjectResult> > -
getReferenceGasPrice(
) → Future< String> -
getTransaction(
String digest, {TransactionIncludeOptions? include}) → Future< TransactionResponse> -
listBalances(
String owner) → Future< List< Balance> > -
listCoins(
String owner, {String coinType = '0x2::sui::SUI', String? cursor, int? limit}) → Future< Page< CoinData> > -
listDynamicFields(
String parentId, {String? cursor, int? limit}) → Future< Page< DynamicFieldEntry> > -
listOwnedObjects(
String owner, {String? objectType, String? cursor, int? limit, ObjectIncludeOptions? include}) → Future< Page< ObjectData> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shutdown(
) → Future< void> -
signAndExecuteTransaction(
SuiAccount account, Transaction tx, {TransactionIncludeOptions? include}) → Future< TransactionResponse> -
Available on SuiGrpcClient, provided by the SuiGrpcClientTransactions extension
Buildstxover gRPC, signs it withaccount, and executes it over gRPC. -
simulateTransaction(
Transaction transactionBlock, {TransactionIncludeOptions? include, bool? doGasSelection}) → Future< TransactionResponse> -
toString(
) → String -
A string representation of this object.
inherited
-
verifyZkLoginSignature(
Uint8List bytes, String signature, {String? address}) → Future< VerifySignatureResult>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited