ExecutionError class
An error that can occur during the execution of a transaction.
- Available extensions
Constructors
- ExecutionError({String? description, Int64? command, ExecutionError_ExecutionErrorKind? kind, MoveAbort? abort, SizeError? sizeError, CommandArgumentError? commandArgumentError, TypeArgumentError? typeArgumentError, PackageUpgradeError? packageUpgradeError, IndexError? indexError, String? objectId, CoinDenyListError? coinDenyListError, CongestedObjects? congestedObjects})
-
factory
-
ExecutionError.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- ExecutionError.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- abort ↔ MoveAbort
-
getter/setter pair
- coinDenyListError ↔ CoinDenyListError
-
getter/setter pair
- command ↔ Int64
-
The command, if any, during which the error occurred.
getter/setter pair
- commandArgumentError ↔ CommandArgumentError
-
getter/setter pair
- congestedObjects ↔ CongestedObjects
-
Set of objects that were congested, leading to the transaction's cancellation.
getter/setter pair
- description ↔ String
-
A human readable description of the error
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- indexError ↔ IndexError
-
getter/setter pair
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - kind ↔ ExecutionError_ExecutionErrorKind
-
getter/setter pair
- objectId ↔ String
-
getter/setter pair
- packageUpgradeError ↔ PackageUpgradeError
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeError ↔ SizeError
-
getter/setter pair
- typeArgumentError ↔ TypeArgumentError
-
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearAbort(
) → void -
clearCoinDenyListError(
) → void -
clearCommand(
) → void -
clearCommandArgumentError(
) → void -
clearCongestedObjects(
) → void -
clearDescription(
) → void -
clearErrorDetails(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearIndexError(
) → void -
clearKind(
) → void -
clearObjectId(
) → void -
clearPackageUpgradeError(
) → void -
clearSizeError(
) → void -
clearTypeArgumentError(
) → void -
clone(
) → ExecutionError - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(ExecutionError)) → ExecutionError -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → ExecutionError - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureAbort(
) → MoveAbort -
ensureCoinDenyListError(
) → CoinDenyListError -
ensureCommandArgumentError(
) → CommandArgumentError -
ensureCongestedObjects(
) → CongestedObjects -
ensureIndexError(
) → IndexError -
ensurePackageUpgradeError(
) → PackageUpgradeError -
ensureSizeError(
) → SizeError -
ensureTypeArgumentError(
) → TypeArgumentError -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasAbort(
) → bool -
hasCoinDenyListError(
) → bool -
hasCommand(
) → bool -
hasCommandArgumentError(
) → bool -
hasCongestedObjects(
) → bool -
hasDescription(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasIndexError(
) → bool -
hasKind(
) → bool -
hasObjectId(
) → bool -
hasPackageUpgradeError(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSizeError(
) → bool -
hasTypeArgumentError(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
whichErrorDetails(
) → ExecutionError_ErrorDetails -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → ExecutionError -
getDefault(
) → ExecutionError