Input class
An input to a user transaction.
- Available extensions
Constructors
-
Input({Input_InputKind? kind, List<
int> ? pure, String? objectId, Int64? version, String? digest, bool? mutable, Input_Mutability? mutability, FundsWithdrawal? fundsWithdrawal, Value? literal}) -
factory
-
Input.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- Input.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- digest ↔ String
-
The digest of this object.
getter/setter pair
- fundsWithdrawal ↔ FundsWithdrawal
-
Fund Reservation information if
kindisFUNDS_WITHDRAWAL.getter/setter pair - hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - kind ↔ Input_InputKind
-
getter/setter pair
- literal ↔ Value
-
A literal value
getter/setter pair
- mutability ↔ Input_Mutability
-
NOTE: For backwards compatibility purposes the addition of the new
NON_EXCLUSIVE_WRITEmutability variant requires providing a new field. The oldmutablefield will continue to be populated and respected as an input for the time being.getter/setter pair - mutable ↔ bool
-
Controls whether the caller asks for a mutable reference to the shared
object.
getter/setter pair
- objectId ↔ String
-
ObjectIdof the object input.getter/setter pair -
pure
↔ List<
int> -
A move value serialized as BCS.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unknownFields → UnknownFieldSet
-
no setterinherited
- version ↔ Int64
-
Requested version of the input object when
kindisIMMUTABLE_OR_OWNEDorRECEIVINGor ifkindisSHAREDthis is the initial version of the object when it was sharedgetter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearDigest(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFundsWithdrawal(
) → void -
clearKind(
) → void -
clearLiteral(
) → void -
clearMutability(
) → void -
clearMutable(
) → void -
clearObjectId(
) → void -
clearPure(
) → void -
clearVersion(
) → void -
clone(
) → Input - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(Input)) → Input -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → Input - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureFundsWithdrawal(
) → FundsWithdrawal -
ensureLiteral(
) → Value -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasDigest(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFundsWithdrawal(
) → bool -
hasKind(
) → bool -
hasLiteral(
) → bool -
hasMutability(
) → bool -
hasMutable(
) → bool -
hasObjectId(
) → bool -
hasPure(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasVersion(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → Input -
getDefault(
) → Input