mutability property
NOTE: For backwards compatibility purposes the addition of the new
NON_EXCLUSIVE_WRITE mutability variant requires providing a new field.
The old mutable field will continue to be populated and respected as an
input for the time being.
Implementation
@$pb.TagNumber(7)
Input_Mutability get mutability => $_getN(6);
Implementation
@$pb.TagNumber(7)
set mutability(Input_Mutability value) => $_setField(7, value);