Object class
An object on the Sui blockchain.
- Available extensions
Constructors
- Object({Bcs? bcs, String? objectId, Int64? version, String? digest, Owner? owner, String? objectType, bool? hasPublicTransfer, Bcs? contents, Package? package, String? previousTransaction, Int64? storageRebate, Value? json, Int64? balance})
-
factory
-
Object.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- Object.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- balance ↔ Int64
-
Current balance if this object is a
0x2::coin::Coin<T>getter/setter pair - bcs ↔ Bcs
-
This Object serialized as BCS.
getter/setter pair
- contents ↔ Bcs
-
BCS bytes of a Move struct value.
getter/setter pair
- digest ↔ String
-
The digest of this Object.
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- hasPublicTransfer ↔ bool
-
DEPRECATED this field is no longer used to determine whether a tx can transfer this
object. Instead, it is always calculated from the objects type when loaded in execution.
getter/setter pair
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - json ↔ Value
-
JSON rendering of the object.
getter/setter pair
- objectId ↔ String
-
ObjectIdfor this object.getter/setter pair - objectType ↔ String
-
The type of this object.
getter/setter pair
- owner ↔ Owner
-
Owner of the object.
getter/setter pair
- package ↔ Package
-
Package information for Move Packages
getter/setter pair
- previousTransaction ↔ String
-
The digest of the transaction that created or last mutated this object
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageRebate ↔ Int64
-
The amount of SUI to rebate if this object gets deleted.
This number is re-calculated each time the object is mutated based on
the present storage gas price.
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- version ↔ Int64
-
Version of the object.
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearBalance(
) → void -
clearBcs(
) → void -
clearContents(
) → void -
clearDigest(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearHasPublicTransfer(
) → void -
clearJson(
) → void -
clearObjectId(
) → void -
clearObjectType(
) → void -
clearOwner(
) → void -
clearPackage(
) → void -
clearPreviousTransaction(
) → void -
clearStorageRebate(
) → void -
clearVersion(
) → void -
clone(
) → Object - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(Object)) → Object -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → Object - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureBcs(
) → Bcs -
ensureContents(
) → Bcs -
ensureJson(
) → Value -
ensureOwner(
) → Owner -
ensurePackage(
) → Package -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasBalance(
) → bool -
hasBcs(
) → bool -
hasContents(
) → bool -
hasDigest(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasHasPublicTransfer(
) → bool -
hasJson(
) → bool -
hasObjectId(
) → bool -
hasObjectType(
) → bool -
hasOwner(
) → bool -
hasPackage(
) → bool -
hasPreviousTransaction(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasStorageRebate(
) → bool -
hasVersion(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → Object -
getDefault(
) → Object