hasPublicTransfer property
DEPRECATED this field is no longer used to determine whether a tx can transfer this object. Instead, it is always calculated from the objects type when loaded in execution.
Only set for Move structs
Implementation
@$pb.TagNumber(7)
$core.bool get hasPublicTransfer => $_getBF(6);
Implementation
@$pb.TagNumber(7)
set hasPublicTransfer($core.bool value) => $_setBool(6, value);