Command class
A single command in a programmable transaction.
- Available extensions
Constructors
- Command({MoveCall? moveCall, TransferObjects? transferObjects, SplitCoins? splitCoins, MergeCoins? mergeCoins, Publish? publish, MakeMoveVector? makeMoveVector, Upgrade? upgrade})
-
factory
-
Command.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- Command.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - makeMoveVector ↔ MakeMoveVector
-
forall T: Vec<T> -> vector<T>Given n-values of the same type, it constructs a vector. For non-objects or an empty vector, the type tag must be specified.getter/setter pair - mergeCoins ↔ MergeCoins
-
(&mut Coin<T>, Vec<Coin<T>>)It merges n-coins into the first coin.getter/setter pair - moveCall ↔ MoveCall
-
A call to either an entry or a public Move function.
getter/setter pair
- publish ↔ Publish
-
Publishes a Move package. It takes the package bytes and a list of the package's transitive
dependencies to link against on chain.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- splitCoins ↔ SplitCoins
-
(&mut Coin<T>, Vec<u64>)->Vec<Coin<T>>It splits off some amounts into new coins with those amounts.getter/setter pair - transferObjects ↔ TransferObjects
-
(Vec<forall T:key+store. T>, address)It sends n-objects to the specified address. These objects must have store (public transfer) and either the previous owner must be an address or the object must be newly created.getter/setter pair - unknownFields → UnknownFieldSet
-
no setterinherited
- upgrade ↔ Upgrade
-
Upgrades a Move package.
Takes (in order):
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearCommand(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearMakeMoveVector(
) → void -
clearMergeCoins(
) → void -
clearMoveCall(
) → void -
clearPublish(
) → void -
clearSplitCoins(
) → void -
clearTransferObjects(
) → void -
clearUpgrade(
) → void -
clone(
) → Command - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(Command)) → Command -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → Command - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureMakeMoveVector(
) → MakeMoveVector -
ensureMergeCoins(
) → MergeCoins -
ensureMoveCall(
) → MoveCall -
ensurePublish(
) → Publish -
ensureSplitCoins(
) → SplitCoins -
ensureTransferObjects(
) → TransferObjects -
ensureUpgrade(
) → Upgrade -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasMakeMoveVector(
) → bool -
hasMergeCoins(
) → bool -
hasMoveCall(
) → bool -
hasPublish(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSplitCoins(
) → bool -
hasTransferObjects(
) → bool -
hasUpgrade(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
whichCommand(
) → Command_Command -
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → Command -
getDefault(
) → Command