Balance class

Constructors

Balance({required String coinType, required String balance, required String coinBalance, required String addressBalance})
const

Properties

addressBalance → String
Held in the address's own Balance<T>, spendable only through a funds-withdrawal input.
final
balance → String
addressBalance plus coinBalance.
final
coinBalance → String
Held as Coin<T> objects.
final
coinType → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited