ChangedObject class

Constructors

ChangedObject({required String objectId, String? idOperation, String? inputState, String? outputState, String? inputVersion, String? inputDigest, Owner? inputOwner, String? outputVersion, String? outputDigest, Owner? outputOwner, String? objectType})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
idOperation → String?
final
inputDigest → String?
final
inputOwner → Owner?
final
inputState → String?
final
inputVersion → String?
final
objectId → String
final
objectType → String?
final
outputDigest → String?
final
outputOwner → Owner?
final
outputState → String?
final
outputVersion → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited