CoinMetadata class

Constructors

CoinMetadata({required String id, required int decimals, required String name, required String symbol, required String description, String? iconUrl})
const

Properties

decimals → int
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
iconUrl → String?
final
id → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbol → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited