ObjectData class

Constructors

ObjectData({required String objectId, required String version, required String digest, required Owner owner, required String type, Uint8List? content, String? previousTransaction, Uint8List? objectBcs, Map<String, dynamic>? json, Map<String, dynamic>? display})
const

Properties

content → Uint8List?
final
digest → String
final
display → Map<String, dynamic>?
Rendered Sui Display (name, image_url, …). Null unless the object's type has a Display template and ObjectIncludeOptions.display was set.
final
hashCode → int
The hash code for this object.
no setterinherited
json → Map<String, dynamic>?
final
objectBcs → Uint8List?
final
objectId → String
final
owner → Owner
final
previousTransaction → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited