ProtocolConfig class

Constructors

ProtocolConfig({required String protocolVersion, required Map<String, bool> featureFlags, required Map<String, String?> attributes})
const

Properties

attributes → Map<String, String?>
final
featureFlags → Map<String, bool>
final
hashCode → int
The hash code for this object.
no setterinherited
protocolVersion → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited