TransactionEffects class
Constructors
-
TransactionEffects({Uint8List? bcs, int? version, String? transactionDigest, String? lamportVersion, ExecutionStatus? status, GasUsed? gasUsed, GasObject? gasObject, List<
String> ? dependencies, List<ChangedObject> ? changedObjects, List<UnchangedConsensusObject> ? unchangedConsensusObjects, String? eventsDigest, String? auxiliaryDataDigest}) -
const
Properties
- auxiliaryDataDigest → String?
-
final
- bcs → Uint8List?
-
final
-
changedObjects
→ List<
ChangedObject> ? -
final
-
dependencies
→ List<
String> ? -
final
- eventsDigest → String?
-
final
- gasObject → GasObject?
-
final
- gasUsed → GasUsed?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lamportVersion → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ExecutionStatus?
-
final
- transactionDigest → String?
-
final
-
unchangedConsensusObjects
→ List<
UnchangedConsensusObject> ? -
final
- version → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited