TransactionError class

Thrown by getTransaction when the digest is unknown.

Implemented types

Constructors

TransactionError(TransactionErrorReason reason, String digest, {Object? cause})
const

Properties

cause → Object?
final
digest → String
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
no setter
reason → TransactionErrorReason
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited