UnchangedConsensusObject class

Constructors

UnchangedConsensusObject({String? kind, required String objectId, required String version, String? digest, String? objectType})
const

Properties

digest → String?
final
hashCode → int
The hash code for this object.
no setterinherited
kind → String?
final
objectId → String
final
objectType → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited