Checkpoint class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
Checkpoint({required String epoch, required String sequenceNumber, required String digest, required String networkTotalTransactions, String? previousDigest, required EpochRollingGasCostSummary epochRollingGasCostSummary, required String timestampMs, required List<
String> transactions, required List checkpointCommitments, required String validatorSignature}) -
constfactory
-
Checkpoint.fromJson(Map<
String, dynamic> json) -
factory
Properties
- checkpointCommitments → List
-
no setterinherited
- digest → String
-
no setterinherited
- epoch → String
-
no setterinherited
- epochRollingGasCostSummary → EpochRollingGasCostSummary
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- networkTotalTransactions → String
-
no setterinherited
- previousDigest → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequenceNumber → String
-
no setterinherited
- timestampMs → String
-
no setterinherited
-
transactions
→ List<
String> -
no setterinherited
- validatorSignature → String
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Checkpoint value)) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Checkpoint value)?) → TResult? -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Checkpoint value)?, {required TResult orElse()}) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String epoch, String sequenceNumber, String digest, String networkTotalTransactions, String? previousDigest, EpochRollingGasCostSummary epochRollingGasCostSummary, String timestampMs, List< String> transactions, List checkpointCommitments, String validatorSignature)?, {required TResult orElse()}) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Checkpoint to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String epoch, String sequenceNumber, String digest, String networkTotalTransactions, String? previousDigest, EpochRollingGasCostSummary epochRollingGasCostSummary, String timestampMs, List< String> transactions, List checkpointCommitments, String validatorSignature)) → TResult -
Available on Checkpoint, provided by the CheckpointPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String epoch, String sequenceNumber, String digest, String networkTotalTransactions, String? previousDigest, EpochRollingGasCostSummary epochRollingGasCostSummary, String timestampMs, List< String> transactions, List checkpointCommitments, String validatorSignature)?) → TResult? -
Available on Checkpoint, provided by the CheckpointPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited