Paged<T> class
abstract
- Available extensions
- Annotations
-
- @Freezed.new(genericArgumentFactories: true)
Constructors
Properties
- data → T
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNextPage → bool
-
no setterinherited
- nextCursor → dynamic
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Paged< T> value)) → TResult -
Available on Paged<
AT> , provided by the PagedPatterns extensionswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Paged< T> value)?) → TResult? -
Available on Paged<
A variant ofT> , provided by the PagedPatterns extensionmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Paged< T> value)?, {required TResult orElse()}) → TResult -
Available on Paged<
A variant ofT> , provided by the PagedPatterns extensionmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(T data, dynamic nextCursor, bool hasNextPage)?, {required TResult orElse()}) → TResult -
Available on Paged<
A variant ofT> , provided by the PagedPatterns extensionwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
Object? toJsonT(T)) → Map< String, dynamic> -
Serializes this Paged to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(T data, dynamic nextCursor, bool hasNextPage)) → TResult -
Available on Paged<
AT> , provided by the PagedPatterns extensionswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(T data, dynamic nextCursor, bool hasNextPage)?) → TResult? -
Available on Paged<
A variant ofT> , provided by the PagedPatterns extensionwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited