ValidatorsApys class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
ValidatorsApys({required List<
ValidatorApy> apys, required String epoch}) -
constfactory
-
ValidatorsApys.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
apys
→ List<
ValidatorApy> -
no setterinherited
- epoch → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ValidatorsApys value)) → TResult -
Available on ValidatorsApys, provided by the ValidatorsApysPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ValidatorsApys value)?) → TResult? -
Available on ValidatorsApys, provided by the ValidatorsApysPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ValidatorsApys value)?, {required TResult orElse()}) → TResult -
Available on ValidatorsApys, provided by the ValidatorsApysPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(List< ValidatorApy> apys, String epoch)?, {required TResult orElse()}) → TResult -
Available on ValidatorsApys, provided by the ValidatorsApysPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ValidatorsApys to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(List< ValidatorApy> apys, String epoch)) → TResult -
Available on ValidatorsApys, provided by the ValidatorsApysPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(List< ValidatorApy> apys, String epoch)?) → TResult? -
Available on ValidatorsApys, provided by the ValidatorsApysPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited