FaucetClient class

Constructors

FaucetClient(String endpoint)

Properties

endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFaucetRequestStatus(String taskId) Future<BatchStatusFaucetResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestSuiFromFaucetV0(String recipient) Future<FaucetResponse>
requestSuiFromFaucetV1(String recipient) Future<BatchFaucetResponse>
requestSuiFromFaucetV2(String recipient) Future<FaucetResponseV2>
Request SUI from the /v2/gas faucet. Throws on non-Success status, or FaucetRateLimitError on HTTP 429.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited