FaucetResponseV2 class
Response from /v2/gas. status is 'Success' or a {Failure: {internal}} map.
Constructors
-
FaucetResponseV2(dynamic status, List<
FaucetCoinInfo> ? coinsSent) - FaucetResponseV2.fromJson(dynamic data)
-
factory
Properties
-
coinsSent
→ List<
FaucetCoinInfo> ? -
final
- failureInternal → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → ObjectId -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited