CoinDenominationInfoResponse class

Constructors

CoinDenominationInfoResponse(String coinType, String? basicUnit, int decimalNumber)

Properties

basicUnit ↔ TransactionDigest?
min unit, like MIST
getter/setter pair
coinType ↔ TransactionDigest
Coin type like "0x2::sui::SUI"
getter/setter pair
decimalNumber ↔ int
number of zeros in the denomination, e.g., 9 here for SUI.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → TransactionDigest
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited